@@ -1,14 +1,16 @@
 #ifndef AUTOGAIN_HPP
 #define AUTOGAIN_HPP
 
-#include <sigc++/sigc++.h>
-#include <array>
 #include "plugin_base.hpp"
 
 class AutoGain : public PluginBase {
  public:
   AutoGain(const std::string& tag, const std::string& schema);
-  ~AutoGain();
+  AutoGain(const AutoGain&) = delete;
+  auto operator=(const AutoGain&) -> AutoGain& = delete;
+  AutoGain(const AutoGain&&) = delete;
+  auto operator=(const AutoGain &&) -> AutoGain& = delete;
+  ~AutoGain() override;
 
   GstElement* autogain = nullptr;
 
