@@ -9,7 +9,10 @@
 class CalibrationMic {
  public:
   CalibrationMic();
-
+  CalibrationMic(const CalibrationMic&) = delete;
+  auto operator=(const CalibrationMic&) -> CalibrationMic& = delete;
+  CalibrationMic(const CalibrationMic&&) = delete;
+  auto operator=(const CalibrationMic &&) -> CalibrationMic& = delete;
   ~CalibrationMic();
 
   std::string log_tag = "calibration_mic: ";
@@ -19,7 +22,7 @@ class CalibrationMic {
   uint min_spectrum_freq = 20;     // Hz
   uint max_spectrum_freq = 20000;  // Hz
   int spectrum_threshold = -120;   // dB
-  uint spectrum_nbands = 3200, spectrum_nfreqs;
+  uint spectrum_nbands = 3200, spectrum_nfreqs = 0;
   uint spectrum_npoints = 300;  // number of points displayed
   float spline_f0, spline_df;
   bool measure_noise = false, subtract_noise = false;
