@@ -1,14 +1,16 @@
 #ifndef CONVOLVER_HPP
 #define CONVOLVER_HPP
 
-#include <sigc++/sigc++.h>
-#include <array>
 #include "plugin_base.hpp"
 
 class Convolver : public PluginBase {
  public:
   Convolver(const std::string& tag, const std::string& schema);
-  ~Convolver();
+  Convolver(const Convolver&) = delete;
+  auto operator=(const Convolver&) -> Convolver& = delete;
+  Convolver(const Convolver&&) = delete;
+  auto operator=(const Convolver &&) -> Convolver& = delete;
+  ~Convolver() override;
 
   GstElement* convolver = nullptr;
 
