@@ -9,7 +9,7 @@ class CrossfeedPreset : public PluginPresetBase {
 
   void write(PresetType preset_type,
              boost::property_tree::ptree& root) override;
-  void read(PresetType preset_type, boost::property_tree::ptree& root) override;
+  void read(PresetType preset_type, const boost::property_tree::ptree& root) override;
 
  private:
   Glib::RefPtr<Gio::Settings> output_settings;
@@ -17,7 +17,7 @@ class CrossfeedPreset : public PluginPresetBase {
   void save(boost::property_tree::ptree& root,
             const std::string& section,
             const Glib::RefPtr<Gio::Settings>& settings) override;
-  void load(boost::property_tree::ptree& root,
+  void load(const boost::property_tree::ptree& root,
             const std::string& section,
             const Glib::RefPtr<Gio::Settings>& settings) override;
 };
