@@ -1,14 +1,16 @@
 #ifndef DEESSER_HPP
 #define DEESSER_HPP
 
-#include <sigc++/sigc++.h>
-#include <array>
 #include "plugin_base.hpp"
 
 class Deesser : public PluginBase {
  public:
   Deesser(const std::string& tag, const std::string& schema);
-  ~Deesser();
+  Deesser(const Deesser&) = delete;
+  auto operator=(const Deesser&) -> Deesser& = delete;
+  Deesser(const Deesser&&) = delete;
+  auto operator=(const Deesser &&) -> Deesser& = delete;
+  ~Deesser() override;
 
   GstElement* deesser = nullptr;
 
