@@ -1,8 +1,6 @@
 #ifndef EQUALIZER_HPP
 #define EQUALIZER_HPP
 
-#include <sigc++/sigc++.h>
-#include <array>
 #include "plugin_base.hpp"
 
 class Equalizer : public PluginBase {
@@ -11,7 +9,11 @@ class Equalizer : public PluginBase {
             const std::string& schema,
             const std::string& schema_left,
             const std::string& schema_right);
-  ~Equalizer();
+  Equalizer(const Equalizer&) = delete;
+  auto operator=(const Equalizer&) -> Equalizer& = delete;
+  Equalizer(const Equalizer&&) = delete;
+  auto operator=(const Equalizer &&) -> Equalizer& = delete;
+  ~Equalizer() override;
 
   GstElement* equalizer = nullptr;
 
@@ -20,7 +22,7 @@ class Equalizer : public PluginBase {
  private:
   GSettings *settings_left = nullptr, *settings_right = nullptr;
 
-  void bind_band(GstElement* equalizer, const int index);
+  void bind_band(GstElement* equalizer, const int& index);
 };
 
 #endif
