@@ -8,7 +8,7 @@ class ReverbPreset : public PluginPresetBase {
   ReverbPreset();
 
   void write(PresetType preset_type, boost::property_tree::ptree& root) override;
-  void read(PresetType preset_type, boost::property_tree::ptree& root) override;
+  void read(PresetType preset_type, const boost::property_tree::ptree& root) override;
 
  private:
   Glib::RefPtr<Gio::Settings> input_settings, output_settings;
@@ -16,7 +16,7 @@ class ReverbPreset : public PluginPresetBase {
   void save(boost::property_tree::ptree& root,
             const std::string& section,
             const Glib::RefPtr<Gio::Settings>& settings) override;
-  void load(boost::property_tree::ptree& root,
+  void load(const boost::property_tree::ptree& root,
             const std::string& section,
             const Glib::RefPtr<Gio::Settings>& settings) override;
 };
