@@ -9,12 +9,14 @@
 
 class SpectrumUi : public Gtk::Grid {
  public:
-  SpectrumUi(BaseObjectType* cobject,
-             const Glib::RefPtr<Gtk::Builder>& builder);
+  SpectrumUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
+  SpectrumUi(const SpectrumUi&) = delete;
+  auto operator=(const SpectrumUi&) -> SpectrumUi& = delete;
+  SpectrumUi(const SpectrumUi&&) = delete;
+  auto operator=(const SpectrumUi &&) -> SpectrumUi& = delete;
+  ~SpectrumUi() override;
 
-  virtual ~SpectrumUi();
-
-  static SpectrumUi* add_to_box(Gtk::Box* box);
+  static auto add_to_box(Gtk::Box* box) -> SpectrumUi*;
 
   void on_new_spectrum(const std::vector<float>& magnitudes);
 
@@ -25,7 +27,7 @@ class SpectrumUi : public Gtk::Grid {
 
   Glib::RefPtr<Gio::Settings> settings;
 
-  Gtk::DrawingArea* spectrum;
+  Gtk::DrawingArea* spectrum = nullptr;
   Gdk::RGBA color, gradient_color;
 
   std::vector<sigc::connection> connections;
@@ -34,13 +36,13 @@ class SpectrumUi : public Gtk::Grid {
   double mouse_intensity = 0, mouse_freq = 0;
   std::vector<float> spectrum_mag;
 
-  bool on_spectrum_draw(const Cairo::RefPtr<Cairo::Context>& ctx);
+  auto on_spectrum_draw(const Cairo::RefPtr<Cairo::Context>& ctx) -> bool;
 
-  bool on_spectrum_enter_notify_event(GdkEventCrossing* event);
+  auto on_spectrum_enter_notify_event(GdkEventCrossing* event) -> bool;
 
-  bool on_spectrum_leave_notify_event(GdkEventCrossing* event);
+  auto on_spectrum_leave_notify_event(GdkEventCrossing* event) -> bool;
 
-  bool on_spectrum_motion_notify_event(GdkEventMotion* event);
+  auto on_spectrum_motion_notify_event(GdkEventMotion* event) -> bool;
 
   void init_color();
 
