@@ -1,7 +1,9 @@
 #include "app_info_ui.hpp"
+#include "blacklist_settings_ui.hpp"
+#include "preset_type.hpp"
+#include "util.hpp"
 #include <glibmm/i18n.h>
 #include <sstream>
-#include "util.hpp"
 
 AppInfoUi::AppInfoUi(BaseObjectType* cobject,
                      const Glib::RefPtr<Gtk::Builder>& builder,
@@ -15,6 +17,7 @@ AppInfoUi::AppInfoUi(BaseObjectType* cobject,
   builder->get_widget("app_name", app_name);
   builder->get_widget("volume", volume);
   builder->get_widget("mute", mute);
+  builder->get_widget("blacklist", blacklist);
   builder->get_widget("mute_icon", mute_icon);
   builder->get_widget("format", format);
   builder->get_widget("rate", rate);
@@ -24,6 +27,11 @@ AppInfoUi::AppInfoUi(BaseObjectType* cobject,
   builder->get_widget("latency", latency);
   builder->get_widget("state", state);
 
+  is_blacklisted =
+      BlacklistSettingsUi::app_is_blacklisted(app_info->name, (app_info->app_type == "sink_input") ? PresetType::output : PresetType::input);
+
+  is_enabled = app_info->connected && !is_blacklisted;
+
   init_widgets();
   connect_signals();
 
@@ -60,7 +68,10 @@ auto AppInfoUi::latency_to_str(uint value) -> std::string {
 }
 
 void AppInfoUi::init_widgets() {
-  enable->set_active(app_info->connected);
+  enable->set_active(is_enabled && !is_blacklisted);
+  enable->set_sensitive(!is_blacklisted);
+
+  blacklist->set_active(is_blacklisted);
 
   app_icon->set_from_icon_name(app_info->icon_name, Gtk::ICON_SIZE_BUTTON);
 
@@ -95,23 +106,52 @@ void AppInfoUi::connect_signals() {
   volume_connection = volume->signal_value_changed().connect(sigc::mem_fun(*this, &AppInfoUi::on_volume_changed));
 
   mute_connection = mute->signal_toggled().connect(sigc::mem_fun(*this, &AppInfoUi::on_mute));
+
+  blacklist_connection = blacklist->signal_clicked().connect([=]() {
+    PresetType preset_type = (app_info->app_type == "sink_input") ? PresetType::output : PresetType::input;
+
+    if (blacklist->get_active()) {
+      // Add new entry to blacklist vector
+      BlacklistSettingsUi::add_new_entry(app_info->name, preset_type);
+      pre_bl_state = is_enabled;
+      is_blacklisted = true;
+      if (is_enabled) {
+        enable->set_active(false);
+      }
+      enable->set_sensitive(false);
+    } else {
+      // Remove app name entry from blacklist vector
+      BlacklistSettingsUi::remove_entry(app_info->name, preset_type);
+      is_blacklisted = false;
+      enable->set_sensitive(true);
+      if (pre_bl_state) {
+        enable->set_active(true);
+      }
+    }
+  });
 }
 
 auto AppInfoUi::on_enable_app(bool state) -> bool {
+  bool success = false;
+
   if (state) {
     if (app_info->app_type == "sink_input") {
-      pm->move_sink_input_to_pulseeffects(app_info->name, app_info->index);
+      success = pm->move_sink_input_to_pulseeffects(app_info->name, app_info->index);
     } else {
-      pm->move_source_output_to_pulseeffects(app_info->name, app_info->index);
+      success = pm->move_source_output_to_pulseeffects(app_info->name, app_info->index);
     }
   } else {
     if (app_info->app_type == "sink_input") {
-      pm->remove_sink_input_from_pulseeffects(app_info->name, app_info->index);
+      success = pm->remove_sink_input_from_pulseeffects(app_info->name, app_info->index);
     } else {
-      pm->remove_source_output_from_pulseeffects(app_info->name, app_info->index);
+      success = pm->remove_source_output_from_pulseeffects(app_info->name, app_info->index);
     }
   }
 
+  if (success) {
+    is_enabled = state;
+  }
+
   return false;
 }
 
@@ -151,6 +191,7 @@ void AppInfoUi::update(const std::shared_ptr<AppInfo>& info) {
   enable_connection.disconnect();
   volume_connection.disconnect();
   mute_connection.disconnect();
+  blacklist_connection.disconnect();
 
   init_widgets();
   connect_signals();
