@@ -74,7 +74,7 @@ ApplicationUi::ApplicationUi(BaseObjectType* cobject,
 
   presets_menu_label->set_text(settings->get_string("last-used-preset"));
 
-  connections.push_back(settings->signal_changed("last-used-preset").connect([=](auto key) {
+  connections.emplace_back(settings->signal_changed("last-used-preset").connect([=](auto key) {
     presets_menu_label->set_text(settings->get_string("last-used-preset"));
   }));
 
