@@ -13,7 +13,7 @@ void CrossfeedPreset::save(boost::property_tree::ptree& root,
   root.put(section + ".crossfeed.feed", settings->get_double("feed"));
 }
 
-void CrossfeedPreset::load(boost::property_tree::ptree& root,
+void CrossfeedPreset::load(const boost::property_tree::ptree& root,
                            const std::string& section,
                            const Glib::RefPtr<Gio::Settings>& settings) {
   update_key<bool>(root, settings, "state", section + ".crossfeed.state");
@@ -29,7 +29,7 @@ void CrossfeedPreset::write(PresetType preset_type, boost::property_tree::ptree&
   }
 }
 
-void CrossfeedPreset::read(PresetType preset_type, boost::property_tree::ptree& root) {
+void CrossfeedPreset::read(PresetType preset_type, const boost::property_tree::ptree& root) {
   if (preset_type == PresetType::output) {
     load(root, "output", output_settings);
   }
