@@ -28,14 +28,14 @@ Delay::Delay(const std::string& tag, const std::string& schema) : PluginBase(tag
     gst_object_unref(GST_OBJECT(pad_sink));
     gst_object_unref(GST_OBJECT(pad_src));
 
-    g_object_set(delay, "bypass", false, nullptr);
+    g_object_set(delay, "enabled", 1, nullptr);
     g_object_set(delay, "mode-l", 2, nullptr);
     g_object_set(delay, "mode-r", 2, nullptr);
-    g_object_set(delay, "dry-l", 0.0f, nullptr);
-    g_object_set(delay, "dry-r", 0.0f, nullptr);
-    g_object_set(delay, "wet-l", 1.0f, nullptr);
-    g_object_set(delay, "wet-r", 1.0f, nullptr);
-    g_object_set(delay, "g-out", 1.0f, nullptr);
+    g_object_set(delay, "dry-l", 0.0F, nullptr);
+    g_object_set(delay, "dry-r", 0.0F, nullptr);
+    g_object_set(delay, "wet-l", 1.0F, nullptr);
+    g_object_set(delay, "wet-r", 1.0F, nullptr);
+    g_object_set(delay, "g-out", 1.0F, nullptr);
 
     bind_to_gsettings();
 
