@@ -10,7 +10,7 @@
 namespace {
 
 auto bandtype_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "Off") == 0) {
     g_value_set_int(value, 0);
@@ -68,7 +68,7 @@ auto int_to_bandtype_enum(const GValue* value, const GVariantType* expected_type
 }
 
 auto mode_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "IIR") == 0) {
     g_value_set_int(value, 0);
@@ -96,7 +96,7 @@ auto int_to_mode_enum(const GValue* value, const GVariantType* expected_type, gp
 }
 
 auto bandmode_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "RLC (BT)") == 0) {
     g_value_set_int(value, 0);
@@ -148,7 +148,7 @@ auto int_to_bandmode_enum(const GValue* value, const GVariantType* expected_type
 }
 
 auto bandslope_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "x1") == 0) {
     g_value_set_int(value, 0);
@@ -198,7 +198,6 @@ EqualizerUi::EqualizerUi(BaseObjectType* cobject,
 
   builder->get_widget("bands_grid_left", bands_grid_left);
   builder->get_widget("bands_grid_right", bands_grid_right);
-  builder->get_widget("reset_eq", reset_eq);
   builder->get_widget("flat_response", flat_response);
   builder->get_widget("calculate_freqs", calculate_freqs);
   builder->get_widget("presets_listbox", presets_listbox);
@@ -206,6 +205,7 @@ EqualizerUi::EqualizerUi(BaseObjectType* cobject,
   builder->get_widget("stack", stack);
   builder->get_widget("stack_switcher", stack_switcher);
   builder->get_widget("mode", mode);
+  builder->get_widget("plugin_reset", reset_button);
 
   get_object(builder, "nbands", nbands);
   get_object(builder, "input_gain", input_gain);
@@ -215,7 +215,8 @@ EqualizerUi::EqualizerUi(BaseObjectType* cobject,
 
   nbands->signal_value_changed().connect(sigc::mem_fun(*this, &EqualizerUi::on_nbands_changed));
 
-  reset_eq->signal_clicked().connect(sigc::mem_fun(*this, &EqualizerUi::reset));
+  // reset equalizer
+  reset_button->signal_clicked().connect(sigc::mem_fun(*this, &EqualizerUi::reset));
 
   flat_response->signal_clicked().connect(sigc::mem_fun(*this, &EqualizerUi::on_flat_response));
 
@@ -223,7 +224,7 @@ EqualizerUi::EqualizerUi(BaseObjectType* cobject,
 
   presets_listbox->set_sort_func(sigc::ptr_fun(&EqualizerUi::on_listbox_sort));
 
-  connections.push_back(settings->signal_changed("split-channels").connect([&](auto key) {
+  connections.emplace_back(settings->signal_changed("split-channels").connect([&](auto key) {
     for (auto c : connections_bands) {
       c.disconnect();
     }
@@ -286,7 +287,7 @@ void EqualizerUi::on_nbands_changed() {
 }
 
 void EqualizerUi::build_bands(Gtk::Grid* bands_grid, const Glib::RefPtr<Gio::Settings>& cfg, const int& nbands) {
-  for (auto c : bands_grid->get_children()) {
+  for (auto* c : bands_grid->get_children()) {
     bands_grid->remove(*c);
 
     delete c;
@@ -297,17 +298,17 @@ void EqualizerUi::build_bands(Gtk::Grid* bands_grid, const Glib::RefPtr<Gio::Set
   for (int n = 0; n < nbands; n++) {
     auto B = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/equalizer_band.glade");
 
-    Gtk::Grid* band_grid;
-    Gtk::ComboBoxText* band_type;
-    Gtk::ComboBoxText* band_mode;
-    Gtk::ComboBoxText* band_slope;
-    Gtk::Label* band_width;
-    Gtk::Label* band_label;
-    Gtk::Button* reset_frequency;
-    Gtk::Button* reset_quality;
-    Gtk::ToggleButton* band_solo;
-    Gtk::ToggleButton* band_mute;
-    Gtk::Scale* band_scale;
+    Gtk::Grid* band_grid = nullptr;
+    Gtk::ComboBoxText* band_type = nullptr;
+    Gtk::ComboBoxText* band_mode = nullptr;
+    Gtk::ComboBoxText* band_slope = nullptr;
+    Gtk::Label* band_width = nullptr;
+    Gtk::Label* band_label = nullptr;
+    Gtk::Button* reset_frequency = nullptr;
+    Gtk::Button* reset_quality = nullptr;
+    Gtk::ToggleButton* band_solo = nullptr;
+    Gtk::ToggleButton* band_mute = nullptr;
+    Gtk::Scale* band_scale = nullptr;
 
     B->get_widget("band_grid", band_grid);
     B->get_widget("band_type", band_type);
@@ -358,19 +359,19 @@ void EqualizerUi::build_bands(Gtk::Grid* bands_grid, const Glib::RefPtr<Gio::Set
       band_label->set_text(msg.str());
     };
 
-    connections_bands.push_back(band_frequency->signal_value_changed().connect(update_w));
+    connections_bands.emplace_back(band_frequency->signal_value_changed().connect(update_w));
 
-    connections_bands.push_back(band_frequency->signal_value_changed().connect(update_band_label));
+    connections_bands.emplace_back(band_frequency->signal_value_changed().connect(update_band_label));
 
-    connections_bands.push_back(band_quality->signal_value_changed().connect(update_w));
+    connections_bands.emplace_back(band_quality->signal_value_changed().connect(update_w));
 
-    connections_bands.push_back(reset_frequency->signal_clicked().connect(
+    connections_bands.emplace_back(reset_frequency->signal_clicked().connect(
         [=]() { cfg->reset(std::string("band" + std::to_string(n) + "-frequency")); }));
 
-    connections_bands.push_back(
+    connections_bands.emplace_back(
         reset_quality->signal_clicked().connect([=]() { cfg->reset(std::string("band" + std::to_string(n) + "-q")); }));
 
-    connections_bands.push_back(band_type->signal_changed().connect([=]() {
+    connections_bands.emplace_back(band_type->signal_changed().connect([=]() {
       if (band_type->get_active_row_number() == 1 || band_type->get_active_row_number() == 3 ||
           band_type->get_active_row_number() == 5 || band_type->get_active_row_number() == 7) {
         band_scale->set_sensitive(true);
@@ -410,7 +411,7 @@ void EqualizerUi::build_unified_bands(const int& nbands) {
     delete c;
   }
 
-  for (auto c : bands_grid_right->get_children()) {
+  for (auto* c : bands_grid_right->get_children()) {
     bands_grid_right->remove(*c);
 
     delete c;
@@ -421,17 +422,17 @@ void EqualizerUi::build_unified_bands(const int& nbands) {
   for (int n = 0; n < nbands; n++) {
     auto B = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/equalizer_band.glade");
 
-    Gtk::Grid* band_grid;
-    Gtk::ComboBoxText* band_type;
-    Gtk::ComboBoxText* band_mode;
-    Gtk::ComboBoxText* band_slope;
-    Gtk::Label* band_width;
-    Gtk::Label* band_label;
-    Gtk::Button* reset_frequency;
-    Gtk::Button* reset_quality;
-    Gtk::ToggleButton* band_solo;
-    Gtk::ToggleButton* band_mute;
-    Gtk::Scale* band_scale;
+    Gtk::Grid* band_grid = nullptr;
+    Gtk::ComboBoxText* band_type = nullptr;
+    Gtk::ComboBoxText* band_mode = nullptr;
+    Gtk::ComboBoxText* band_slope = nullptr;
+    Gtk::Label* band_width = nullptr;
+    Gtk::Label* band_label = nullptr;
+    Gtk::Button* reset_frequency = nullptr;
+    Gtk::Button* reset_quality = nullptr;
+    Gtk::ToggleButton* band_solo = nullptr;
+    Gtk::ToggleButton* band_mute = nullptr;
+    Gtk::Scale* band_scale = nullptr;
 
     B->get_widget("band_grid", band_grid);
     B->get_widget("band_type", band_type);
@@ -482,52 +483,52 @@ void EqualizerUi::build_unified_bands(const int& nbands) {
       band_label->set_text(msg.str());
     };
 
-    connections_bands.push_back(band_frequency->signal_value_changed().connect(update_w));
+    connections_bands.emplace_back(band_frequency->signal_value_changed().connect(update_w));
 
-    connections_bands.push_back(band_frequency->signal_value_changed().connect(update_band_label));
+    connections_bands.emplace_back(band_frequency->signal_value_changed().connect(update_band_label));
 
-    connections_bands.push_back(band_quality->signal_value_changed().connect(update_w));
+    connections_bands.emplace_back(band_quality->signal_value_changed().connect(update_w));
 
     /*right channel
       we need the bindgins below for the right channel equalizer to be updated
       they have to be before the bindings for the left channel.
      */
 
-    connections_bands.push_back(band_gain->signal_value_changed().connect([=]() {
+    connections_bands.emplace_back(band_gain->signal_value_changed().connect([=]() {
       settings_right->set_double(std::string("band" + std::to_string(n) + "-gain"), band_gain->get_value());
     }));
 
-    connections_bands.push_back(band_frequency->signal_value_changed().connect([=]() {
+    connections_bands.emplace_back(band_frequency->signal_value_changed().connect([=]() {
       settings_right->set_double(std::string("band" + std::to_string(n) + "-frequency"), band_frequency->get_value());
     }));
 
-    connections_bands.push_back(band_quality->signal_value_changed().connect([=]() {
+    connections_bands.emplace_back(band_quality->signal_value_changed().connect([=]() {
       settings_right->set_double(std::string("band" + std::to_string(n) + "-q"), band_quality->get_value());
     }));
 
-    connections_bands.push_back(band_type->signal_changed().connect([=]() {
+    connections_bands.emplace_back(band_type->signal_changed().connect([=]() {
       settings_right->set_enum(std::string("band" + std::to_string(n) + "-type"), band_type->get_active_row_number());
     }));
 
-    connections_bands.push_back(band_mode->signal_changed().connect([=]() {
+    connections_bands.emplace_back(band_mode->signal_changed().connect([=]() {
       settings_right->set_enum(std::string("band" + std::to_string(n) + "-mode"), band_mode->get_active_row_number());
     }));
 
-    connections_bands.push_back(band_slope->signal_changed().connect([=]() {
+    connections_bands.emplace_back(band_slope->signal_changed().connect([=]() {
       settings_right->set_enum(std::string("band" + std::to_string(n) + "-slope"), band_slope->get_active_row_number());
     }));
 
-    connections_bands.push_back(band_solo->signal_toggled().connect([=]() {
+    connections_bands.emplace_back(band_solo->signal_toggled().connect([=]() {
       settings_right->set_boolean(std::string("band" + std::to_string(n) + "-solo"), band_solo->get_active());
     }));
 
-    connections_bands.push_back(band_mute->signal_toggled().connect([=]() {
+    connections_bands.emplace_back(band_mute->signal_toggled().connect([=]() {
       settings_right->set_boolean(std::string("band" + std::to_string(n) + "-mute"), band_mute->get_active());
     }));
 
     // left channel
 
-    connections_bands.push_back(band_type->signal_changed().connect([=]() {
+    connections_bands.emplace_back(band_type->signal_changed().connect([=]() {
       if (band_type->get_active_row_number() == 1 || band_type->get_active_row_number() == 3 ||
           band_type->get_active_row_number() == 5 || band_type->get_active_row_number() == 7) {
         band_scale->set_sensitive(true);
@@ -536,13 +537,13 @@ void EqualizerUi::build_unified_bands(const int& nbands) {
       }
     }));
 
-    connections_bands.push_back(reset_frequency->signal_clicked().connect([=]() {
+    connections_bands.emplace_back(reset_frequency->signal_clicked().connect([=]() {
       settings_left->reset(std::string("band" + std::to_string(n) + "-frequency"));
 
       settings_right->reset(std::string("band" + std::to_string(n) + "-frequency"));
     }));
 
-    connections_bands.push_back(reset_quality->signal_clicked().connect([=]() {
+    connections_bands.emplace_back(reset_quality->signal_clicked().connect([=]() {
       settings_left->reset(std::string("band" + std::to_string(n) + "-q"));
 
       settings_right->reset(std::string("band" + std::to_string(n) + "-q"));
@@ -587,9 +588,9 @@ void EqualizerUi::on_flat_response() {
 void EqualizerUi::on_calculate_frequencies() {
   const double min_freq = 20.0;
   const double max_freq = 20000.0;
-  double freq0;
-  double freq1;
-  double step;
+  double freq0 = 0.0;
+  double freq1 = 0.0;
+  double step = 0.0;
 
   int nbands = settings->get_int("num-bands");
 
@@ -622,13 +623,13 @@ void EqualizerUi::on_calculate_frequencies() {
 }
 
 void EqualizerUi::load_preset(const std::string& file_name) {
-  gsize dsize;
+  gsize dsize = 0;
   std::stringstream ss;
   boost::property_tree::ptree root;
 
   auto bytes = Gio::Resource::lookup_data_global(presets_path + file_name);
 
-  auto rdata = static_cast<const char*>(bytes->get_data(dsize));
+  const auto* rdata = static_cast<const char*>(bytes->get_data(dsize));
 
   auto file_contents = std::string(rdata);
 
@@ -715,7 +716,7 @@ auto EqualizerUi::on_listbox_sort(Gtk::ListBoxRow* row1, Gtk::ListBoxRow* row2)
 void EqualizerUi::populate_presets_listbox() {
   auto children = presets_listbox->get_children();
 
-  for (auto c : children) {
+  for (auto* c : children) {
     presets_listbox->remove(*c);
   }
 
@@ -726,9 +727,9 @@ void EqualizerUi::populate_presets_listbox() {
 
     auto b = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/equalizer_preset_row.glade");
 
-    Gtk::ListBoxRow* row;
-    Gtk::Button* apply_btn;
-    Gtk::Label* label;
+    Gtk::ListBoxRow* row = nullptr;
+    Gtk::Button* apply_btn = nullptr;
+    Gtk::Label* label = nullptr;
 
     b->get_widget("preset_row", row);
     b->get_widget("apply", apply_btn);
@@ -738,7 +739,7 @@ void EqualizerUi::populate_presets_listbox() {
 
     label->set_text(name);
 
-    connections.push_back(apply_btn->signal_clicked().connect([=]() { load_preset(row->get_name() + ".json"); }));
+    connections.emplace_back(apply_btn->signal_clicked().connect([=]() { load_preset(row->get_name() + ".json"); }));
 
     presets_listbox->add(*row);
 
@@ -747,34 +748,39 @@ void EqualizerUi::populate_presets_listbox() {
 }
 
 void EqualizerUi::reset() {
-  settings->reset("state");
-  settings->reset("mode");
-  settings->reset("num-bands");
-  settings->reset("split-channels");
-  settings->reset("input-gain");
-  settings->reset("output-gain");
+  try {
+    settings->reset("mode");
+    settings->reset("num-bands");
+    settings->reset("split-channels");
+    settings->reset("input-gain");
+    settings->reset("output-gain");
 
-  for (int n = 0; n < 30; n++) {
-    // left channel
+    for (int n = 0; n < 30; n++) {
+      // left channel
 
-    settings_left->reset(std::string("band" + std::to_string(n) + "-gain"));
-    settings_left->reset(std::string("band" + std::to_string(n) + "-frequency"));
-    settings_left->reset(std::string("band" + std::to_string(n) + "-q"));
-    settings_left->reset(std::string("band" + std::to_string(n) + "-type"));
-    settings_left->reset(std::string("band" + std::to_string(n) + "-mode"));
-    settings_left->reset(std::string("band" + std::to_string(n) + "-slope"));
-    settings_left->reset(std::string("band" + std::to_string(n) + "-solo"));
-    settings_left->reset(std::string("band" + std::to_string(n) + "-mute"));
+      settings_left->reset(std::string("band" + std::to_string(n) + "-gain"));
+      settings_left->reset(std::string("band" + std::to_string(n) + "-frequency"));
+      settings_left->reset(std::string("band" + std::to_string(n) + "-q"));
+      settings_left->reset(std::string("band" + std::to_string(n) + "-type"));
+      settings_left->reset(std::string("band" + std::to_string(n) + "-mode"));
+      settings_left->reset(std::string("band" + std::to_string(n) + "-slope"));
+      settings_left->reset(std::string("band" + std::to_string(n) + "-solo"));
+      settings_left->reset(std::string("band" + std::to_string(n) + "-mute"));
 
-    // right channel
+      // right channel
 
-    settings_right->reset(std::string("band" + std::to_string(n) + "-gain"));
-    settings_right->reset(std::string("band" + std::to_string(n) + "-frequency"));
-    settings_right->reset(std::string("band" + std::to_string(n) + "-q"));
-    settings_right->reset(std::string("band" + std::to_string(n) + "-type"));
-    settings_right->reset(std::string("band" + std::to_string(n) + "-mode"));
-    settings_right->reset(std::string("band" + std::to_string(n) + "-slope"));
-    settings_right->reset(std::string("band" + std::to_string(n) + "-solo"));
-    settings_right->reset(std::string("band" + std::to_string(n) + "-mute"));
+      settings_right->reset(std::string("band" + std::to_string(n) + "-gain"));
+      settings_right->reset(std::string("band" + std::to_string(n) + "-frequency"));
+      settings_right->reset(std::string("band" + std::to_string(n) + "-q"));
+      settings_right->reset(std::string("band" + std::to_string(n) + "-type"));
+      settings_right->reset(std::string("band" + std::to_string(n) + "-mode"));
+      settings_right->reset(std::string("band" + std::to_string(n) + "-slope"));
+      settings_right->reset(std::string("band" + std::to_string(n) + "-solo"));
+      settings_right->reset(std::string("band" + std::to_string(n) + "-mute"));
+    }
+
+    util::debug(name + " plugin: successfully reset");
+  } catch (std::exception& e) {
+    util::debug(name + " plugin: an error occurred during reset process");
   }
 }
