@@ -10,6 +10,7 @@ MaximizerUi::MaximizerUi(BaseObjectType* cobject,
 
   builder->get_widget("reduction", reduction);
   builder->get_widget("reduction_label", reduction_label);
+  builder->get_widget("plugin_reset", reset_button);
 
   get_object(builder, "ceiling", ceiling);
   get_object(builder, "release", release);
@@ -23,12 +24,31 @@ MaximizerUi::MaximizerUi(BaseObjectType* cobject,
   settings->bind("ceiling", ceiling.get(), "value", flag);
   settings->bind("release", release.get(), "value", flag);
   settings->bind("threshold", threshold.get(), "value", flag);
+
+  // reset plugin
+  reset_button->signal_clicked().connect([=]() { reset(); });
 }
 
 MaximizerUi::~MaximizerUi() {
   util::debug(name + " ui destroyed");
 }
 
+void MaximizerUi::reset() {
+  try {
+    std::string section = (preset_type == PresetType::output) ? "output" : "input";
+
+    update_default_key<double>(settings, "release", section + "maximizer.release");
+
+    update_default_key<double>(settings, "ceiling", section + "maximizer.ceiling");
+    
+    update_default_key<double>(settings, "threshold", section + "maximizer.threshold");
+
+    util::debug(name + " plugin: successfully reset");
+  } catch (std::exception& e) {
+    util::debug(name + " plugin: an error occurred during reset process");
+  }
+}
+
 void MaximizerUi::on_new_reduction(double value) {
   reduction->set_value(value);
 
