@@ -86,6 +86,7 @@ MultibandCompressorUi::MultibandCompressorUi(BaseObjectType* cobject,
   builder->get_widget("compression2_label", compression2_label);
   builder->get_widget("compression3", compression3);
   builder->get_widget("compression3_label", compression3_label);
+  builder->get_widget("plugin_reset", reset_button);
 
   get_object(builder, "input_gain", input_gain);
   get_object(builder, "output_gain", output_gain);
@@ -176,12 +177,117 @@ MultibandCompressorUi::MultibandCompressorUi(BaseObjectType* cobject,
 
   g_settings_bind_with_mapping(settings->gobj(), "detection3", detection3->gobj(), "active", G_SETTINGS_BIND_DEFAULT,
                                detection_enum_to_int, int_to_detection_enum, nullptr, nullptr);
+
+  // reset plugin
+  reset_button->signal_clicked().connect([=]() { reset(); });
 }
 
 MultibandCompressorUi::~MultibandCompressorUi() {
   util::debug(name + " ui destroyed");
 }
 
+void MultibandCompressorUi::reset() {
+  try {
+    std::string section = (preset_type == PresetType::output) ? "output" : "input";
+
+    update_default_key<double>(settings, "input-gain", section + ".multiband_compressor.input-gain");
+
+    update_default_key<double>(settings, "output-gain", section + ".multiband_compressor.output-gain");
+
+    update_default_key<double>(settings, "freq0", section + ".multiband_compressor.freq0");
+
+    update_default_key<double>(settings, "freq1", section + ".multiband_compressor.freq1");
+
+    update_default_key<double>(settings, "freq2", section + ".multiband_compressor.freq2");
+
+    update_default_string_key(settings, "mode", section + ".multiband_compressor.mode");
+
+    // sub band
+
+    update_default_key<double>(settings, "threshold0", section + ".multiband_compressor.subband.threshold");
+
+    update_default_key<double>(settings, "ratio0", section + ".multiband_compressor.subband.ratio");
+
+    update_default_key<double>(settings, "attack0", section + ".multiband_compressor.subband.attack");
+
+    update_default_key<double>(settings, "release0", section + ".multiband_compressor.subband.release");
+
+    update_default_key<double>(settings, "makeup0", section + ".multiband_compressor.subband.makeup");
+
+    update_default_key<double>(settings, "knee0", section + ".multiband_compressor.subband.knee");
+
+    update_default_string_key(settings, "detection0", section + ".multiband_compressor.subband.detection");
+
+    update_default_key<bool>(settings, "bypass0", section + ".multiband_compressor.subband.bypass");
+
+    update_default_key<bool>(settings, "solo0", section + ".multiband_compressor.subband.solo");
+
+    // low band
+
+    update_default_key<double>(settings, "threshold1", section + ".multiband_compressor.lowband.threshold");
+
+    update_default_key<double>(settings, "ratio1", section + ".multiband_compressor.lowband.ratio");
+
+    update_default_key<double>(settings, "attack1", section + ".multiband_compressor.lowband.attack");
+
+    update_default_key<double>(settings, "release1", section + ".multiband_compressor.lowband.release");
+
+    update_default_key<double>(settings, "makeup1", section + ".multiband_compressor.lowband.makeup");
+
+    update_default_key<double>(settings, "knee1", section + ".multiband_compressor.lowband.knee");
+
+    update_default_string_key(settings, "detection1", section + ".multiband_compressor.lowband.detection");
+
+    update_default_key<bool>(settings, "bypass1", section + ".multiband_compressor.lowband.bypass");
+
+    update_default_key<bool>(settings, "solo1", section + ".multiband_compressor.lowband.solo");
+
+    // mid band
+
+    update_default_key<double>(settings, "threshold2", section + ".multiband_compressor.midband.threshold");
+
+    update_default_key<double>(settings, "ratio2", section + ".multiband_compressor.midband.ratio");
+
+    update_default_key<double>(settings, "attack2", section + ".multiband_compressor.midband.attack");
+
+    update_default_key<double>(settings, "release2", section + ".multiband_compressor.midband.release");
+
+    update_default_key<double>(settings, "makeup2", section + ".multiband_compressor.midband.makeup");
+
+    update_default_key<double>(settings, "knee2", section + ".multiband_compressor.midband.knee");
+
+    update_default_string_key(settings, "detection2", section + ".multiband_compressor.midband.detection");
+
+    update_default_key<bool>(settings, "bypass2", section + ".multiband_compressor.midband.bypass");
+
+    update_default_key<bool>(settings, "solo2", section + ".multiband_compressor.midband.solo");
+
+    // high band
+
+    update_default_key<double>(settings, "threshold3", section + ".multiband_compressor.highband.threshold");
+
+    update_default_key<double>(settings, "ratio3", section + ".multiband_compressor.highband.ratio");
+
+    update_default_key<double>(settings, "attack3", section + ".multiband_compressor.highband.attack");
+
+    update_default_key<double>(settings, "release3", section + ".multiband_compressor.highband.release");
+
+    update_default_key<double>(settings, "makeup3", section + ".multiband_compressor.highband.makeup");
+
+    update_default_key<double>(settings, "knee3", section + ".multiband_compressor.highband.knee");
+
+    update_default_string_key(settings, "detection3", section + ".multiband_compressor.highband.detection");
+
+    update_default_key<bool>(settings, "bypass3", section + ".multiband_compressor.highband.bypass");
+
+    update_default_key<bool>(settings, "solo3", section + ".multiband_compressor.highband.solo");
+
+    util::debug(name + " plugin: successfully reset");
+  } catch (std::exception& e) {
+    util::debug(name + " plugin: an error occurred during reset process");
+  }
+}
+
 void MultibandCompressorUi::on_new_output0(double value) {
   output0->set_value(value);
 
