@@ -769,7 +769,7 @@ void PulseManager::find_sources() {
   pa_threaded_mainloop_unlock(main_loop);
 }
 
-void PulseManager::move_sink_input_to_pulseeffects(const std::string& name, uint idx) {
+auto PulseManager::move_sink_input_to_pulseeffects(const std::string& name, uint idx) -> bool {
   struct Data {
     std::string name;
     uint idx;
@@ -778,6 +778,8 @@ void PulseManager::move_sink_input_to_pulseeffects(const std::string& name, uint
 
   Data data = {name, idx, this};
 
+  bool added_successfully = false;
+
   pa_threaded_mainloop_lock(main_loop);
 
   auto o = pa_context_move_sink_input_by_index(
@@ -802,14 +804,18 @@ void PulseManager::move_sink_input_to_pulseeffects(const std::string& name, uint
     }
 
     pa_operation_unref(o);
+
+    added_successfully = true;
   } else {
     util::critical(log_tag + "failed to move sink input: " + name + ", idx = " + std::to_string(idx) + " to PE");
   }
 
   pa_threaded_mainloop_unlock(main_loop);
+
+  return added_successfully;
 }
 
-void PulseManager::remove_sink_input_from_pulseeffects(const std::string& name, uint idx) {
+auto PulseManager::remove_sink_input_from_pulseeffects(const std::string& name, uint idx) -> bool {
   struct Data {
     std::string name;
     uint idx;
@@ -818,6 +824,8 @@ void PulseManager::remove_sink_input_from_pulseeffects(const std::string& name,
 
   Data data = {name, idx, this};
 
+  bool removed_successfully = false;
+
   pa_threaded_mainloop_lock(main_loop);
 
   auto o = pa_context_move_sink_input_by_name(
@@ -843,14 +851,18 @@ void PulseManager::remove_sink_input_from_pulseeffects(const std::string& name,
     }
 
     pa_operation_unref(o);
+
+    removed_successfully = true;
   } else {
     util::critical(log_tag + "failed to remove sink input: " + name + ", idx = " + std::to_string(idx) + " from PE");
   }
 
   pa_threaded_mainloop_unlock(main_loop);
+
+  return removed_successfully;
 }
 
-void PulseManager::move_source_output_to_pulseeffects(const std::string& name, uint idx) {
+auto PulseManager::move_source_output_to_pulseeffects(const std::string& name, uint idx) -> bool {
   struct Data {
     std::string name;
     uint idx;
@@ -859,6 +871,8 @@ void PulseManager::move_source_output_to_pulseeffects(const std::string& name, u
 
   Data data = {name, idx, this};
 
+  bool added_successfully = false;
+
   pa_threaded_mainloop_lock(main_loop);
 
   auto o = pa_context_move_source_output_by_index(
@@ -883,14 +897,18 @@ void PulseManager::move_source_output_to_pulseeffects(const std::string& name, u
     }
 
     pa_operation_unref(o);
+
+    added_successfully = true;
   } else {
     util::critical(log_tag + "failed to move source output: " + name + ", idx = " + std::to_string(idx) + " to PE");
   }
 
   pa_threaded_mainloop_unlock(main_loop);
+
+  return added_successfully;
 }
 
-void PulseManager::remove_source_output_from_pulseeffects(const std::string& name, uint idx) {
+auto PulseManager::remove_source_output_from_pulseeffects(const std::string& name, uint idx) -> bool {
   struct Data {
     std::string name;
     uint idx;
@@ -899,6 +917,8 @@ void PulseManager::remove_source_output_from_pulseeffects(const std::string& nam
 
   Data data = {name, idx, this};
 
+  bool removed_successfully = false;
+
   pa_threaded_mainloop_lock(main_loop);
 
   auto o = pa_context_move_source_output_by_name(
@@ -922,11 +942,15 @@ void PulseManager::remove_source_output_from_pulseeffects(const std::string& nam
     }
 
     pa_operation_unref(o);
+
+    removed_successfully = true;
   } else {
     util::critical(log_tag + "failed to remove source output: " + name + ", idx = " + std::to_string(idx) + " from PE");
   }
 
   pa_threaded_mainloop_unlock(main_loop);
+
+  return removed_successfully;
 }
 
 void PulseManager::set_sink_input_volume(const std::string& name, uint idx, uint8_t channels, uint value) {
@@ -1304,16 +1328,9 @@ void PulseManager::new_app(const pa_sink_input_info* info) {
   auto app_info = parse_app_info(info);
 
   if (app_info != nullptr) {
-    // checking if the user blacklisted this app
+    app_info->app_type = "sink_input";
 
-    auto forbidden_app =
-        std::find(std::begin(blacklist_out), std::end(blacklist_out), app_info->name) != std::end(blacklist_out);
-
-    if (!forbidden_app) {
-      app_info->app_type = "sink_input";
-
-      Glib::signal_idle().connect_once([&, app_info = move(app_info)]() { sink_input_added.emit(app_info); });
-    }
+    Glib::signal_idle().connect_once([&, app_info = move(app_info)]() { sink_input_added.emit(app_info); });
   }
 }
 
@@ -1321,16 +1338,9 @@ void PulseManager::new_app(const pa_source_output_info* info) {
   auto app_info = parse_app_info(info);
 
   if (app_info != nullptr) {
-    // checking if the user blacklisted this app
+    app_info->app_type = "source_output";
 
-    auto forbidden_app =
-        std::find(std::begin(blacklist_in), std::end(blacklist_in), app_info->name) != std::end(blacklist_in);
-
-    if (!forbidden_app) {
-      app_info->app_type = "source_output";
-
-      Glib::signal_idle().connect_once([&, app_info = move(app_info)]() { source_output_added.emit(app_info); });
-    }
+    Glib::signal_idle().connect_once([&, app_info = move(app_info)]() { source_output_added.emit(app_info); });
   }
 }
 
