@@ -57,6 +57,10 @@ SinkInputEffectsUi::SinkInputEffectsUi(BaseObjectType* cobject,
   b_autogain->get_widget_derived("widgets_grid", autogain_ui, "com.github.wwmm.pulseeffects.sinkinputs.autogain");
   b_delay->get_widget_derived("widgets_grid", delay_ui, "com.github.wwmm.pulseeffects.sinkinputs.delay");
 
+  // preset_type inside user interfaces already initialized to "output"; nothing to be done
+
+  // add to stack
+
   stack->add(*limiter_ui, limiter_ui->name);
   stack->add(*compressor_ui, compressor_ui->name);
   stack->add(*filter_ui, filter_ui->name);
@@ -133,6 +137,39 @@ auto SinkInputEffectsUi::add_to_stack(Gtk::Stack* stack, SinkInputEffects* sie_p
   return ui;
 }
 
+void SinkInputEffectsUi::on_app_added(std::shared_ptr<AppInfo> app_info) {
+  // Blacklist check
+  auto forbidden_app = BlacklistSettingsUi::app_is_blacklisted(app_info->name, PresetType::output);
+
+  if (forbidden_app) {
+    app_info->visible = BlacklistSettingsUi::get_blacklisted_apps_visibility();
+
+    if (!app_info->visible) {
+      return;
+    }
+  } else {
+    app_info->visible = true;
+  }
+
+  // Duplicate entry check
+  for (const auto& a : apps_list) {
+    if (a->app_info->index == app_info->index) {
+      // do not add the same app two times in the interface
+      return;
+    }
+  }
+
+  auto builder = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/app_info.glade");
+
+  AppInfoUi* appui = nullptr;
+
+  builder->get_widget_derived("widgets_grid", appui, app_info, pm);
+
+  apps_box->add(*appui);
+
+  apps_list.emplace_back(appui);
+}
+
 void SinkInputEffectsUi::level_meters_connections() {
   // limiter level meters connections
 
