@@ -37,6 +37,22 @@ SourceOutputEffectsUi::SourceOutputEffectsUi(BaseObjectType* cobject,
   b_multiband_gate->get_widget_derived("widgets_grid", multiband_gate_ui,
                                        "com.github.wwmm.pulseeffects.sourceoutputs.multibandgate");
 
+  // set preset type property inside user interfaces to be intepreted as "input"
+
+  limiter_ui->preset_type = PresetType::input;
+  compressor_ui->preset_type = PresetType::input;
+  filter_ui->preset_type = PresetType::input;
+  equalizer_ui->preset_type = PresetType::input;
+  reverb_ui->preset_type = PresetType::input;
+  gate_ui->preset_type = PresetType::input;
+  deesser_ui->preset_type = PresetType::input;
+  pitch_ui->preset_type = PresetType::input;
+  webrtc_ui->preset_type = PresetType::input;
+  multiband_compressor_ui->preset_type = PresetType::input;
+  multiband_gate_ui->preset_type = PresetType::input;
+
+  // add to stack
+
   stack->add(*limiter_ui, limiter_ui->name);
   stack->add(*compressor_ui, compressor_ui->name);
   stack->add(*filter_ui, filter_ui->name);
@@ -96,6 +112,39 @@ auto SourceOutputEffectsUi::add_to_stack(Gtk::Stack* stack, SourceOutputEffects*
   return ui;
 }
 
+void SourceOutputEffectsUi::on_app_added(std::shared_ptr<AppInfo> app_info) {
+  // Blacklist check
+  auto forbidden_app = BlacklistSettingsUi::app_is_blacklisted(app_info->name, PresetType::input);
+
+  if (forbidden_app) {
+    app_info->visible = BlacklistSettingsUi::get_blacklisted_apps_visibility();
+
+    if (!app_info->visible) {
+      return;
+    }
+  } else {
+    app_info->visible = true;
+  }
+
+  // Duplicate entry check
+  for (const auto& a : apps_list) {
+    if (a->app_info->index == app_info->index) {
+      // do not add the same app two times in the interface
+      return;
+    }
+  }
+
+  auto builder = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/app_info.glade");
+
+  AppInfoUi* appui = nullptr;
+
+  builder->get_widget_derived("widgets_grid", appui, app_info, pm);
+
+  apps_box->add(*appui);
+
+  apps_list.emplace_back(appui);
+}
+
 void SourceOutputEffectsUi::level_meters_connections() {
   // limiter level meters connections
 
